about summary refs log tree commit diff
path: root/pkgs/misc/emulators
diff options
context:
space:
mode:
authorSandro <sandro.jaeckel@gmail.com>2021-01-29 02:17:30 +0100
committerGitHub <noreply@github.com>2021-01-29 02:17:30 +0100
commitb52146a0df02d3e8ce02ee7259970c1ea48ac20f (patch)
treea7d9ef00c98802c4b8dc3f370742332067dcaa9c /pkgs/misc/emulators
parentf05284c43101114e89462a1342b79062d16fe986 (diff)
parenta02eba70302c94ae486ad0d6de3fbe5137294e40 (diff)
downloadnixlib-b52146a0df02d3e8ce02ee7259970c1ea48ac20f.tar
nixlib-b52146a0df02d3e8ce02ee7259970c1ea48ac20f.tar.gz
nixlib-b52146a0df02d3e8ce02ee7259970c1ea48ac20f.tar.bz2
nixlib-b52146a0df02d3e8ce02ee7259970c1ea48ac20f.tar.lz
nixlib-b52146a0df02d3e8ce02ee7259970c1ea48ac20f.tar.xz
nixlib-b52146a0df02d3e8ce02ee7259970c1ea48ac20f.tar.zst
nixlib-b52146a0df02d3e8ce02ee7259970c1ea48ac20f.zip
Merge pull request #111045 from IvarWithoutBones/fix-ryujinx
ryujinx: 1.0.6416 -> 1.0.6448
Diffstat (limited to 'pkgs/misc/emulators')
-rw-r--r--pkgs/misc/emulators/ryujinx/default.nix15
-rw-r--r--pkgs/misc/emulators/ryujinx/disable-updater.patch33
2 files changed, 43 insertions, 5 deletions
diff --git a/pkgs/misc/emulators/ryujinx/disable-updater.patch b/pkgs/misc/emulators/ryujinx/disable-updater.patch
new file mode 100644
index 000000000000..e233aec7ca13
--- /dev/null
+++ b/pkgs/misc/emulators/ryujinx/disable-updater.patch
@@ -0,0 +1,33 @@
+diff --git a/Ryujinx/Program.cs b/Ryujinx/Program.cs
+index 29043bb8..d3973c7c 100644
+--- a/Ryujinx/Program.cs
++++ b/Ryujinx/Program.cs
+@@ -54,9 +54,6 @@ namespace Ryujinx
+                 }
+             }
+
+-            // Delete backup files after updating.
+-            Task.Run(Updater.CleanupUpdate);
+-
+             Toolkit.Init(new ToolkitOptions
+             {
+                 Backend = PlatformBackend.PreferNative
+@@ -146,11 +143,6 @@ namespace Ryujinx
+                 mainWindow.LoadApplication(launchPathArg);
+             }
+
+-            if (ConfigurationState.Instance.CheckUpdatesOnStart.Value && Updater.CanUpdate(false))
+-            {
+-                _ = Updater.BeginParse(mainWindow, false);
+-            }
+-
+             Application.Run();
+         }
+
+@@ -200,4 +192,4 @@ namespace Ryujinx
+             Logger.Shutdown();
+         }
+     }
+-}
+\ No newline at end of file
++}
diff --git a/pkgs/misc/emulators/ryujinx/default.nix b/pkgs/misc/emulators/ryujinx/default.nix
index c30ab195180f..db6e75b9d4e8 100644
--- a/pkgs/misc/emulators/ryujinx/default.nix
+++ b/pkgs/misc/emulators/ryujinx/default.nix
@@ -1,6 +1,6 @@
 { lib, stdenv, fetchFromGitHub, fetchurl, makeWrapper, makeDesktopItem, linkFarmFromDrvs
 , dotnet-sdk_5, dotnetPackages, dotnetCorePackages
-, SDL2, libX11, openal
+, SDL2, libX11, ffmpeg, openal, libsoundio
 , gtk3, gobject-introspection, gdk-pixbuf, wrapGAppsHook
 }:
 
@@ -9,17 +9,19 @@ let
     SDL2
     gtk3
     libX11
+    ffmpeg
     openal
+    libsoundio
   ];
 in stdenv.mkDerivation rec {
   pname = "ryujinx";
-  version = "1.0.6416"; # Versioning is based off of the official appveyor builds: https://ci.appveyor.com/project/gdkchan/ryujinx
+  version = "1.0.6448"; # Versioning is based off of the official appveyor builds: https://ci.appveyor.com/project/gdkchan/ryujinx
 
   src = fetchFromGitHub {
     owner = "Ryujinx";
     repo = "Ryujinx";
-    rev = "ad491b5570ec428d0d87d56426b03125e2ca5220";
-    sha256 = "0gjrvdh6n26r9kkljiw9xvmvb47vmpwsjxi4iv41ir3nsdigdvsn";
+    rev = "9eb0ab05c6e820e113b3c61cbacd9b085b2819c4";
+    sha256 = "168nm7p6lqswmsya6gf3296ligyjabqmbrdzginkcviii643yslz";
   };
 
   nativeBuildInputs = [ dotnet-sdk_5 dotnetPackages.Nuget makeWrapper wrapGAppsHook gobject-introspection gdk-pixbuf ];
@@ -32,7 +34,10 @@ in stdenv.mkDerivation rec {
     };
   });
 
-  patches = [ ./log.patch ]; # Without this, Ryujinx tries to write logs to the nix store. This patch makes it write to "~/.config/Ryujinx/Logs" on Linux.
+  patches = [
+    ./log.patch # Without this, Ryujinx attempts to write logs to the nix store. This patch makes it write to "~/.config/Ryujinx/Logs" on Linux.
+    ./disable-updater.patch # This disables the auto-updater, which does not work as it attempts to modify the nix store.
+  ];
 
   configurePhase = ''
     runHook preConfigure